==> sale-3.1.7-2.jar: iot/sqls/getNewAllWebHandPlan.sql <==
SELECT
 left(f_prices,len(f_prices)) f_price,
 case when f_last_tablebase1 is null then 0 else f_last_tablebase1 end f_last_tablebase,
 case when f_tablebase1 is null then 0 else f_tablebase1 end f_tablebase,
 *
FROM (
	SELECT
		h.f_price_id,
		ui.f_input_date,
		mr.f_user_id hpid,
		mr.f_userfiles_id,
		a.f_address,
		u.f_userinfo_code,
    case when h.f_price is null then pf.value else h.f_price end f_prices,
		mr.id,
		mr.f_userinfo_id,
		mr.f_user_name,
		mr.f_user_id,
		mr.f_meternumber,
		mr.f_tablebase f_tablebase1,
		mr.f_last_tablebase f_last_tablebase1,
		mr.f_insert_date,
		mr.f_signal,
		mr.f_batterylevel,
		mr.f_valvestate,
		mr.f_software_version,
		mr.f_table_msg,
		mr.f_last_meter_state_msg,
		mr.f_hand_date,
		mr.f_last_hand_date,
		mr.f_upload_type,
		mr.f_jval,
		ui.f_user_type,
		ui.f_gasproperties,
		gb.f_meter_brand,
		gm.f_meter_style,
		ui.f_depname,
		u.f_filialeid,
		ui.f_gas_date,
		ui.f_table_state,
		ui.f_balance_amount f_balance_amount,
		isnull(h.f_oughtamount,0) f_oughtamount,
		isnull(h.f_oughtfee,0) f_oughtfee,
		h.f_curbalance,
		h.f_balance,
		h.id hid,
		gb.f_alias,                                         --表厂别名
-- 		p.f_parameter_date,
		mr.f_nsturalgas_data,                               --24小时用气量
	    mr.f_snr                                          --信噪比
		--case when p.f_parameter_state is null then '未标记' else f_parameter_state end f_parameter_state
	FROM
		t_meteread mr
		--left join t_handplan h on h.f_meteread_id=mr.id
		LEFT JOIN t_userfiles ui ON (ui.f_userfiles_id = mr.f_userfiles_id and ui.f_meternumber = mr.f_meternumber)
		LEFT JOIN t_userinfo u ON (u.f_userinfo_id = ui.f_userinfo_id)
		LEFT JOIN t_user_address a ON (a.f_userinfo_id = ui.f_userinfo_id)
		left join t_gasbrand gb on ui.f_gasbrand_id = gb.id
		left join t_gasmodel gm on ui.f_gasmodel_id = gm.id
	/*	left join (select f_meternumber,'已标记' f_parameter_state,max(f_parameter_date) f_parameter_date
		        from t_userparameter where f_parameter_state='待处理' GROUP BY f_meternumber
						having COUNT(*)>0) p
		    on ui.f_meternumber=p.f_meternumber*/
		LEFT JOIN (select * from t_stairprice where f_state='有效') sp ON ( sp.f_price_id= ui.f_price_id )
		LEFT JOIN (SELECT f_stairprice_id,VALUE= (STUFF((SELECT '/' + CONVERT ( VARCHAR ( 12 ), f_price ) FROM t_detailprice WHERE f_stairprice_id = Test.f_stairprice_id FOR XML PATH ( '' ) ),1,1,'' ) )
			FROM t_detailprice AS Test GROUP BY f_stairprice_id ) pF ON (Pf.f_stairprice_id= sp.id)
		left join (
			select
				f_price_id,
				f_meteread_id,
				f_curbalance,
				f_oughtamount,
				f_oughtfee,
				f_balance,
				id,
				cast((select cast(f_price as varchar)+' ' from t_chargeprice where f_hand_id = h1.id for xml path('')) as varchar) f_price
			from t_handplan h1
		) h on h.f_meteread_id=mr.id
where  {condition}
) A
ORDER BY
	A.id DESC

==> sale-3.5.4.jar: iot/sqls/getNewAllWebHandPlan.sql <==
SELECT
 {entity.findDialect()==$SqlServer$: $left(f_prices,len(f_prices))$,$substr(f_prices,0,length(f_prices))$} as f_price,
 case when f_last_tablebase1 is null then 0 else f_last_tablebase1 end f_last_tablebase,
 case when f_tablebase1 is null then 0 else f_tablebase1 end f_tablebase,
 A.*
FROM (
	SELECT
		h.f_price_id,
		ui.f_input_date,
		mr.f_user_id hpid,
		mr.f_userfiles_id,
		a.f_address,
		u.f_userinfo_code,
    case when h.f_price is null then pf.value else h.f_price end f_prices,
		mr.id,
		mr.f_userinfo_id,
		mr.f_user_name,
		mr.f_user_id,
		mr.f_meternumber,
		mr.f_tablebase f_tablebase1,
		mr.f_last_tablebase f_last_tablebase1,
		mr.f_insert_date,
		mr.f_signal,
		mr.f_batterylevel,
		mr.f_valvestate,
		mr.f_software_version,
		mr.f_table_msg,
		mr.f_last_meter_state_msg,
		mr.f_hand_date,
		mr.f_last_hand_date,
		mr.f_upload_type,
		mr.f_jval,
		ui.f_user_type,
		ui.f_gasproperties,
		gb.f_meter_brand,
		gm.f_meter_style,
		ui.f_depname,
		u.f_filialeid,
		ui.f_gas_date,
		ui.f_table_state,
		ui.f_balance_amount f_balance_amount,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(h.f_oughtamount,0) f_oughtamount,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(h.f_oughtfee,0) f_oughtfee,
		h.f_curbalance,
		h.f_balance,
		h.id hid,
		gb.f_alias,                                         --表厂别名
-- 		p.f_parameter_date,
		mr.f_nsturalgas_data,                               --24小时用气量
	    mr.f_snr                                          --信噪比
		--case when p.f_parameter_state is null then '未标记' else f_parameter_state end f_parameter_state
	FROM
		t_meteread mr
		--left join t_handplan h on h.f_meteread_id=mr.id
		LEFT JOIN t_userfiles ui ON (ui.f_userfiles_id = mr.f_userfiles_id and ui.f_meternumber = mr.f_meternumber)
		LEFT JOIN t_userinfo u ON (u.f_userinfo_id = ui.f_userinfo_id)
		LEFT JOIN t_user_address a ON (a.f_userinfo_id = ui.f_userinfo_id)
		left join t_gasbrand gb on ui.f_gasbrand_id = gb.id
		left join t_gasmodel gm on ui.f_gasmodel_id = gm.id
	/*	left join (select f_meternumber,'已标记' f_parameter_state,max(f_parameter_date) f_parameter_date
		        from t_userparameter where f_parameter_state='待处理' GROUP BY f_meternumber
						having COUNT(*)>0) p
		    on ui.f_meternumber=p.f_meternumber*/
		LEFT JOIN (select * from t_stairprice where f_state='有效') sp ON ( sp.f_price_id= ui.f_price_id )
		LEFT JOIN (
        SELECT f_stairprice_id,
        {entity.findDialect()==$SqlServer$:
$
VALUE= (STUFF((SELECT '/' + CONVERT ( VARCHAR ( 12 ), f_price ) FROM t_detailprice WHERE f_stairprice_id = Test.f_stairprice_id FOR XML PATH ( '' ) ),1,1,'' ) )
FROM t_detailprice AS Test GROUP BY f_stairprice_id )$
,$
LISTAGG(f_price,'/') WITHIN GROUP( ORDER BY f_price) as VALUE FROM
		T_DETAILPRICE
	GROUP BY
		f_stairprice_id  )
$}
         pF ON (Pf.f_stairprice_id= sp.id)
		left join (
			select
				f_price_id,
				f_meteread_id,
				f_curbalance,
				f_oughtamount,
				f_oughtfee,
				f_balance,
				id,
{entity.findDialect()==$SqlServer$:
$
				cast((select cast(f_price as varchar)+' ' from t_chargeprice where f_hand_id = h1.id for xml path('')) as varchar) f_price

$,$
(select f_price ||' ' from t_chargeprice where f_hand_id = h1.id)  f_price
$}
			from t_handplan h1
		) h on h.f_meteread_id=mr.id
where  {condition}
) A
ORDER BY
	A.id DESC
